# XRTpy

[![License](https://img.shields.io/badge/License-BSD%202--Clause-blue.svg)](./LICENSE)
[![GitHub Actions — CI](https://github.com/HinodeXRT/xrtpy/workflows/CI/badge.svg)](https://github.com/HinodeXRT/xrtpy/actions?query=workflow%3ACI+branch%3Amain)
[![Read the Docs Status](https://readthedocs.org/projects/xrtpy/badge/?version=latest&logo=twitter)](http://xrtpy.readthedocs.io/en/latest/?badge=latest)
[![astropy](http://img.shields.io/badge/powered%20by-AstroPy-orange.svg?style=flat&logo=astropy)](http://www.astropy.org/)

XRTpy is a Python package being developed for the analysis of observations
made by the X-Ray Telescope (XRT) on the *Hinode* spacecraft.

## Acknowledgements

The development of XRTpy is supported by NASA contract NNM07AB07C to the
Smithsonian Astrophysical Observatory.
